@@ -6,6 +6,8 @@ echo "::group::nauty"
 
 source $(dirname "$0")/common.sh
 
+./install_scripts_opt/install_nmz_hash-library.sh
+
 if [ "$GMP_INSTALLDIR" != "" ]; then
     CPPFLAGS="${CPPFLAGS} -I${GMP_INSTALLDIR}/include"
     LDFLAGS="${LDFLAGS} -L${GMP_INSTALLDIR}/lib"
@@ -14,9 +16,10 @@ fi
 ##  script for the installation of nauty
 ## as far as needed by libnormaliz
 
-NAUTY_VERSION="27r1"
-NAUTY_URL="http://pallini.di.uniroma1.it/nauty${NAUTY_VERSION}.tar.gz"
-NAUTY_SHA256=76ca5d196e402c83a987f90c28ff706bcc5a333bb4a8fbb979a62d3b99c34e77
+NAUTY_VERSION="27r3"
+# NAUTY_URL="https://pallini.di.uniroma1.it/nauty${NAUTY_VERSION}.tar.gz"
+NAUTY_URL="https://users.cecs.anu.edu.au/~bdm/nauty/nauty${NAUTY_VERSION}.tar.gz"
+NAUTY_SHA256=4f0665b716a53f7a14ea2ae30059f23d064ce3fe4c12c013404ef6e1ee0b88c2
 
 echo "Installing nauty..."
 
@@ -35,6 +38,11 @@ make all -j4 CFLAGS="-fPIC -O3"
 mkdir -p ${PREFIX}/include/nauty
 cp nauty.h ${PREFIX}/include/nauty
 # mkdir -p ${PREFIX}/lib ## in common.sh
-cp nauty.a ${PREFIX}/lib/libnauty.a
+if [ "$OSTYPE" != "msys" ]; then
+	cp nauty.a ${PREFIX}/lib/libnauty.a ## WORDSIZE = 64
+else
+	cp nautyW.a ${PREFIX}/lib/libnauty.a ## WORDSIZE = 32
+fi
+
 
 echo "nauty installed"
