@@ -66,7 +66,7 @@ bool AutomorphismGroup<Integer>::IsIntegral() const {
 
 template <typename Integer>
 bool AutomorphismGroup<Integer>::IsInput() const {
-    return HasQuality(AutomParam::input_gen) || HasQuality(AutomParam::input_gen);
+    return HasQuality(AutomParam::input_gen) || HasQuality(AutomParam::input_ineq);
 }
 
 template <typename Integer>
@@ -319,6 +319,9 @@ template <typename Integer>
 AutomorphismGroup<Integer>::AutomorphismGroup(const Matrix<Integer>& ExtRays,
                                               const Matrix<Integer>& SuppHyps,
                                               const Matrix<Integer>& SpecialLinForms) {
+
+    // SuppHyps.debug_print('+');
+    // ExtRays.debug_print('$');
     reset();
     size_t dim = ExtRays.nr_of_columns();
     Matrix<Integer> SpecialGens(0, dim);
@@ -1314,7 +1317,7 @@ vector<vector<key_t> > orbits(const vector<vector<key_t> >& Perms, size_t N) {
     if (Perms.size() == 0) {  // each element is its own orbit
         Orbits.reserve(N);
         for (size_t i = 0; i < N; ++i)
-            Orbits.push_back(vector<key_t>(1, i));
+            Orbits.push_back(vector<key_t>(1, static_cast<key_t>(i)));
         return Orbits;
     }
     vector<bool> InOrbit(N, false);
@@ -1322,7 +1325,7 @@ vector<vector<key_t> > orbits(const vector<vector<key_t> >& Perms, size_t N) {
         if (InOrbit[i])
             continue;
         vector<key_t> NewOrbit;
-        NewOrbit.push_back(i);
+        NewOrbit.push_back(static_cast<key_t>(i));
         InOrbit[i] = true;
         for (size_t j = 0; j < NewOrbit.size(); ++j) {
             for (const auto& Perm : Perms) {
@@ -1347,7 +1350,7 @@ vector<vector<key_t> > convert_to_orbits(const vector<key_t>& raw_orbits) {
     for (key_t i = 0; i < raw_orbits.size(); ++i) {
         if (raw_orbits[i] == i) {
             orbits.push_back(vector<key_t>(1, i));
-            key[i] = orbits.size() - 1;
+            key[i] = static_cast<key_t>(orbits.size() - 1);
         }
         else {
             orbits[key[raw_orbits[i]]].push_back(i);
@@ -1357,7 +1360,7 @@ vector<vector<key_t> > convert_to_orbits(const vector<key_t>& raw_orbits) {
 }
 
 vector<vector<key_t> > cycle_decomposition(vector<key_t> perm, bool with_fixed_points) {
-    // computes the cacle decomposition of a permutation with or wothout fixed points
+    // computes the cacle decomposition of a permutation with or without fixed points
 
     vector<vector<key_t> > dec;
     vector<bool> in_cycle(perm.size(), false);
@@ -1367,14 +1370,14 @@ vector<vector<key_t> > cycle_decomposition(vector<key_t> perm, bool with_fixed_p
         if (perm[i] == i) {
             if (!with_fixed_points)
                 continue;
-            vector<key_t> cycle(1, i);
+            vector<key_t> cycle(1, static_cast<key_t>(i));
             in_cycle[i] = true;
             dec.push_back(cycle);
             continue;
         }
         in_cycle[i] = true;
-        key_t next = i;
-        vector<key_t> cycle(1, i);
+        key_t next = static_cast<key_t>(i);
+        vector<key_t> cycle(1, static_cast<key_t>(i));
         while (true) {
             next = perm[next];
             if (next == i)
@@ -1418,4 +1421,4 @@ template class Isomorphism_Classes<renf_elem_class>;
 template class IsoType<renf_elem_class>;
 #endif
 
-}  // namespace libnormaliz
\ No newline at end of file
+}  // namespace libnormaliz
