@@ -1,6 +1,6 @@
 /*
  * Normaliz
- * Copyright (C) 2007-2021  W. Bruns, B. Ichim, Ch. Soeger, U. v. d. Ohe
+ * Copyright (C) 2007-2022  W. Bruns, B. Ichim, Ch. Soeger, U. v. d. Ohe
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -12,7 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * As an exception, when this program is distributed through (i) the App Store
  * by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or (iii) Google Play
@@ -62,8 +62,8 @@ ConeProperties::ConeProperties(const bitset<ConeProperty::EnumSize>& props) {
 
 /* set Properties */
 ConeProperties& ConeProperties::set(bool value) {
-    for(size_t i=0;i<CPs.size();++i)
-        CPs[i]=value;
+    for (size_t i = 0; i < CPs.size(); ++i)
+        CPs[i] = value;
     return *this;
 }
 
@@ -102,7 +102,7 @@ ConeProperties& ConeProperties::reset(const ConeProperties& ConeProps) {
 }
 
 ConeProperties ConeProperties::intersection_with(const ConeProperties& ConeProps) const {
-    ConeProperties ret=*this;
+    ConeProperties ret = *this;
     ret.CPs &= ConeProps.CPs;
     return ret;
 }
@@ -123,7 +123,6 @@ ConeProperties ConeProperties::options() const {
     return intersection_with(all_options());
 }
 
-
 // rturn cps with ALL options/goals set
 ConeProperties all_options() {
     ConeProperties ret;
@@ -163,6 +162,20 @@ ConeProperties all_options() {
     ret.set(ConeProperty::GradingIsPositive);
     ret.set(ConeProperty::Dynamic);
     ret.set(ConeProperty::Static);
+    ret.set(ConeProperty::SignedDec);
+    ret.set(ConeProperty::NoSignedDec);
+    ret.set(ConeProperty::ExploitIsosMult);
+    ret.set(ConeProperty::StrictIsoTypeCheck);
+    ret.set(ConeProperty::WritePreComp);
+    ret.set(ConeProperty::Lex);
+    ret.set(ConeProperty::RevLex);
+    ret.set(ConeProperty::DegLex);
+    ret.set(ConeProperty::WritePreComp); // is not really an option, but taken care of in options.h
+    ret.set(ConeProperty::NoPatching);
+    ret.set(ConeProperty::NoCoarseProjection);
+    ret.set(ConeProperty::SingleLatticePointInternal);
+    ret.set(ConeProperty::MaxDegRepresentations);
+    ret.set(ConeProperty::ConeForMonoid);
     return ret;
 }
 
@@ -171,10 +184,9 @@ ConeProperties all_goals() {
     ret.set();
     ret.reset(all_options());
     return ret;
-    
 }
 
-ConeProperties only_inhomogeneous_props(){
+ConeProperties only_inhomogeneous_props() {
     static ConeProperties ret;
     ret.set(ConeProperty::VerticesOfPolyhedron);
     ret.set(ConeProperty::ModuleGenerators);
@@ -184,7 +196,7 @@ ConeProperties only_inhomogeneous_props(){
     return ret;
 }
 
-ConeProperties treated_as_hom_props(){
+ConeProperties treated_as_hom_props() {
     static ConeProperties ret;
     ret.set(ConeProperty::WeightedEhrhartSeries);
     ret.set(ConeProperty::Integral);
@@ -203,7 +215,7 @@ ConeProperties treated_as_hom_props(){
     return ret;
 }
 
-ConeProperties only_homogeneous_props(){
+ConeProperties only_homogeneous_props() {
     static ConeProperties ret;
     ret.set(ConeProperty::Deg1Elements);
     ret.set(ConeProperty::Dehomogenization);
@@ -212,11 +224,16 @@ ConeProperties only_homogeneous_props(){
     ret.set(ConeProperty::IsDeg1ExtremeRays);
     ret.set(ConeProperty::IsDeg1HilbertBasis);
     ret.set(ConeProperty::IsIntegrallyClosed);
+    ret.set(ConeProperty::IsSerreR1);
+    ret.set(ConeProperty::IsLatticeIdealToric);
     ret.set(ConeProperty::IsReesPrimary);
     ret.set(ConeProperty::ReesPrimaryMultiplicity);
     ret.set(ConeProperty::IsGorenstein);
     ret.set(ConeProperty::ClassGroup);
     ret.set(ConeProperty::UnitGroupIndex);
+    ret.set(ConeProperty::SingularLocus);
+    ret.set(ConeProperty::CodimSingularLocus);
+    ret.set(ConeProperty::Representations);
     return ret;
 }
 
@@ -234,23 +251,87 @@ ConeProperties all_full_cone_goals(bool renf) {
     ret.set(ConeProperty::ModuleRank);
     ret.set(ConeProperty::IsPointed);
     ret.set(ConeProperty::IsIntegrallyClosed);
-    ret.set(ConeProperty::IsEmptySemiOpen); 
+    ret.set(ConeProperty::IsEmptySemiOpen);
     ret.set(ConeProperty::BasicTriangulation);
     ret.set(ConeProperty::BasicStanleyDec);
-    ret.set(ConeProperty::ConeDecomposition);    
+    ret.set(ConeProperty::ConeDecomposition);
     ret.set(ConeProperty::Automorphisms);
     ret.set(ConeProperty::RationalAutomorphisms);
-    ret.set(ConeProperty::HilbertSeries); 
+    ret.set(ConeProperty::HilbertSeries);
     ret.set(ConeProperty::DefaultMode);
     ret.set(ConeProperty::ClassGroup);
     ret.set(ConeProperty::HSOP);
     ret.set(ConeProperty::Generators);
     ret.set(ConeProperty::Grading);
-    if(renf)
+    if (renf)
         ret.set(ConeProperty::Volume);
     return ret;
 }
 
+void ConeProperties::check_monoid_goals() const{
+    ConeProperties copy(*this);
+    copy = copy.goals();
+    copy.reset(ConeProperty::HilbertBasis);
+    copy.reset(ConeProperty::IsIntegrallyClosed);
+    copy.reset(ConeProperty::IsSerreR1);
+    copy.reset(ConeProperty::Multiplicity);
+    copy.reset(ConeProperty::Grading);
+    copy.reset(ConeProperty::HilbertSeries);
+    copy.reset(ConeProperty::HilbertQuasiPolynomial);
+    copy.reset(ConeProperty::MarkovBasis);
+    copy.reset(ConeProperty::GroebnerBasis);
+    copy.reset(ConeProperty::AmbientAutomorphisms);
+    copy.reset(ConeProperty::InputAutomorphisms);
+    copy.reset(ConeProperty::Representations);
+    copy.reset(ConeProperty::SingularLocus);
+    copy.reset(ConeProperty::CodimSingularLocus);
+    copy.reset(ConeProperty::Lex);
+    copy.reset(ConeProperty::DegLex);
+    copy.reset(ConeProperty::RevLex);
+    copy.reset(ConeProperty::IsSerreR1);
+    if (copy.any()) {
+        errorOutput() << copy << endl;
+        throw BadInputException("Cone Property in last line not allowed for monoids");
+    }
+}
+
+void ConeProperties::check_lattice_ideal_goals() const{
+    ConeProperties copy(*this);
+    copy = copy.goals();
+    copy.reset(ConeProperty::MarkovBasis);
+    copy.reset(ConeProperty::GroebnerBasis);
+    copy.reset(ConeProperty::Lex);
+    copy.reset(ConeProperty::DegLex);
+    copy.reset(ConeProperty::RevLex);
+    copy.reset(ConeProperty::IsLatticeIdealToric);
+    if (copy.any()) {
+        errorOutput() << copy << endl;
+        throw BadInputException("Cone Property in last line not allowed for lattice ideals");
+    }
+}
+
+ConeProperties all_automorphisms() {
+    static ConeProperties ret;
+    ret.set(ConeProperty::Automorphisms);
+    ret.set(ConeProperty::RationalAutomorphisms);
+    ret.set(ConeProperty::EuclideanAutomorphisms);
+    ret.set(ConeProperty::InputAutomorphisms);
+    ret.set(ConeProperty::AmbientAutomorphisms);
+    ret.set(ConeProperty::CombinatorialAutomorphisms);
+    return ret;
+}
+
+ConeProperties all_triangulations() {
+    static ConeProperties ret;
+    ret.set(ConeProperty::Triangulation);
+    ret.set(ConeProperty::UnimodularTriangulation);
+    ret.set(ConeProperty::LatticePointTriangulation);
+    ret.set(ConeProperty::AllGeneratorsTriangulation);
+    ret.set(ConeProperty::PullingTriangulation);
+    ret.set(ConeProperty::PlacingTriangulation);
+    return ret;
+}
+
 ConeProperties all_goals_using_grading(bool inhomogeneous) {
     static ConeProperties ret;
     ret.set(ConeProperty::Deg1Elements);
@@ -268,20 +349,19 @@ ConeProperties all_goals_using_grading(bool inhomogeneous) {
     ret.set(ConeProperty::WeightedEhrhartQuasiPolynomial);
     ret.set(ConeProperty::VirtualMultiplicity);
     ret.set(ConeProperty::Integral);
-    if(!inhomogeneous)
+    if (!inhomogeneous)
         ret.set(ConeProperty::IntegerHull);
     return ret;
 }
 
-ConeProperties ConeProperties::full_cone_goals(bool renf) const{    
-    return intersection_with(all_full_cone_goals(renf)); 
+ConeProperties ConeProperties::full_cone_goals(bool renf) const {
+    return intersection_with(all_full_cone_goals(renf));
 }
 
-ConeProperties ConeProperties::goals_using_grading(bool inhomogeneous) const{    
-    return intersection_with(all_goals_using_grading(inhomogeneous)); 
+ConeProperties ConeProperties::goals_using_grading(bool inhomogeneous) const {
+    return intersection_with(all_goals_using_grading(inhomogeneous));
 }
 
-
 /* test which/how many properties are set */
 bool ConeProperties::test(ConeProperty::Enum Property) const {
     return CPs.test(Property);
@@ -298,30 +378,44 @@ size_t ConeProperties::count() const {
 
 /* add preconditions */
 void ConeProperties::set_preconditions(bool inhomogeneous, bool numberfield) {
-    if ((CPs.test(ConeProperty::ExploitAutomsMult) || CPs.test(ConeProperty::ExploitAutomsVectors)) ||
-        CPs.test(ConeProperty::AmbientAutomorphisms)) {
+
+    if(CPs.test(ConeProperty::GroebnerBasis) ||
+                CPs.test(ConeProperty::MarkovBasis)){
+        CPs.set(ConeProperty::HilbertBasis);
+        CPs.set(ConeProperty::IsPointed);
+    }
+
+    if(CPs.test(ConeProperty::MaxDegRepresentations))
+        CPs.set(ConeProperty::Representations);
+
+    if (CPs.test(ConeProperty::ExploitAutomsVectors)) {
         errorOutput() << *this << endl;
         throw BadInputException("At least one of the listed computation goals not yet implemernted");
     }
-    
-    if(CPs.test(ConeProperty::CoveringFace))
-        CPs.set(ConeProperty::IsEmptySemiOpen);
-    
-    if(CPs.test(ConeProperty::IsEmptySemiOpen))
+
+    if(CPs.test(ConeProperty::SingleLatticePoint))
+        CPs.set(ConeProperty::NoGradingDenom);
+
+    if (CPs.test(ConeProperty::WritePreComp)) {  // the following are needed for precomputed data
         CPs.set(ConeProperty::SupportHyperplanes);
-    
+        CPs.set(ConeProperty::ExtremeRays);
+        CPs.set(ConeProperty::Sublattice);
+    }
+
+    if (CPs.test(ConeProperty::CoveringFace))
+        CPs.set(ConeProperty::IsEmptySemiOpen);
+
+    if (CPs.test(ConeProperty::IsEmptySemiOpen))
+        CPs.set(ConeProperty::SupportHyperplanes);
+
     // unimodular triangulation ==> HilbertBasis
     if (CPs.test(ConeProperty::UnimodularTriangulation))
         CPs.set(ConeProperty::HilbertBasis);
-    
+
     // lattice point  triangulation ==> LatticePoints
     if (CPs.test(ConeProperty::LatticePointTriangulation))
         CPs.set(ConeProperty::LatticePoints);
 
-    if ((CPs.test(ConeProperty::ExploitAutomsMult) || CPs.test(ConeProperty::ExploitAutomsVectors)) &&
-        !CPs.test(ConeProperty::AmbientAutomorphisms))
-        CPs.set(ConeProperty::Automorphisms);
-
     // RenfVolume ==> Volume
     if (CPs.test(ConeProperty::RenfVolume)) {
         CPs.set(ConeProperty::Volume);
@@ -336,7 +430,7 @@ void ConeProperties::set_preconditions(bool inhomogeneous, bool numberfield) {
     if (CPs.test(ConeProperty::EhrhartQuasiPolynomial))
         CPs.set(ConeProperty::EhrhartSeries);
 
-    // homogenous && EhrhartSeies ==> HilbertSeries
+    // homogeneous && EhrhartSeies ==> HilbertSeries
     if (CPs.test(ConeProperty::EhrhartSeries) && !inhomogeneous) {
         CPs.set(ConeProperty::HilbertSeries);
         CPs.set(ConeProperty::NoGradingDenom);
@@ -350,9 +444,9 @@ void ConeProperties::set_preconditions(bool inhomogeneous, bool numberfield) {
     // Integral ==> Integral
     if (CPs.test(ConeProperty::EuclideanIntegral))
         CPs.set(ConeProperty::Integral);
-    
+
     // LatticePointTriangulation ==> LatticePoints
-   if(CPs.test(ConeProperty::LatticePointTriangulation))
+    if (CPs.test(ConeProperty::LatticePointTriangulation))
         CPs.set(ConeProperty::LatticePoints);
 
     // inhomogeneous && LatticePoints ==> HilbertBasis (ModuleGenerators if renf)
@@ -379,7 +473,6 @@ void ConeProperties::set_preconditions(bool inhomogeneous, bool numberfield) {
         CPs.reset(ConeProperty::LatticePoints);
     }
 
-
     if (inhomogeneous && CPs.test(ConeProperty::HilbertBasis)) {
         CPs.reset(ConeProperty::NumberLatticePoints);
     }
@@ -392,7 +485,7 @@ void ConeProperties::set_preconditions(bool inhomogeneous, bool numberfield) {
         CPs.set(ConeProperty::NoGradingDenom);
     }
 
-        // homogeneous && Volume ==> Multiplicity
+    // homogeneous && Volume ==> Multiplicity
     if (!inhomogeneous && CPs.test(ConeProperty::Volume) && !numberfield) {
         CPs.set(ConeProperty::Multiplicity);
     }
@@ -403,13 +496,13 @@ void ConeProperties::set_preconditions(bool inhomogeneous, bool numberfield) {
         if (!inhomogeneous)
             CPs.set(ConeProperty::Grading);
     }
-    
+
     if (CPs.test(ConeProperty::ExtremeRaysFloat)) {
         CPs.set(ConeProperty::SupportHyperplanes);
         CPs.set(ConeProperty::ExtremeRays);
     }
 
-    // SuppHypsFloat ==> SupportHyperplanes 
+    // SuppHypsFloat ==> SupportHyperplanes
     if (CPs.test(ConeProperty::SuppHypsFloat)) {
         CPs.set(ConeProperty::SupportHyperplanes);
     }
@@ -438,13 +531,13 @@ void ConeProperties::set_preconditions(bool inhomogeneous, bool numberfield) {
         CPs.set(ConeProperty::HilbertBasis);
         CPs.set(ConeProperty::Grading);
     }
-    
+
     // Iseg1ExtremeRays ==> ExtremeRays + Grading
     if (CPs.test(ConeProperty::IsDeg1ExtremeRays)) {
         CPs.set(ConeProperty::ExtremeRays);
         CPs.set(ConeProperty::Grading);
     }
-    
+
     // Grading ==> Generators
     if (CPs.test(ConeProperty::Grading))
         CPs.set(ConeProperty::Generators);
@@ -477,17 +570,21 @@ void ConeProperties::set_preconditions(bool inhomogeneous, bool numberfield) {
     // ConeDecomposition ==> Triangulation
     if (CPs.test(ConeProperty::ConeDecomposition))
         CPs.set(ConeProperty::Triangulation);
-    
+
     // Stanley decompition  ==> Triangulation
-    if (CPs.test(ConeProperty::StanleyDec)){
+    if (CPs.test(ConeProperty::StanleyDec)) {
         CPs.set(ConeProperty::Triangulation);
         CPs.set(ConeProperty::BasicStanleyDec);
-    }    
-    
+    }
+
+    if (CPs.test(ConeProperty::PlacingTriangulation)) {
+        CPs.set(ConeProperty::KeepOrder);
+    }
+
     // refined triangulation ==> Triangulation
-    if (CPs.test(ConeProperty::UnimodularTriangulation) || CPs.test(ConeProperty::LatticePointTriangulation)
-                        || CPs.test(ConeProperty::AllGeneratorsTriangulation) 
-                        || CPs.test(ConeProperty::Triangulation) )
+    if (CPs.test(ConeProperty::UnimodularTriangulation) || CPs.test(ConeProperty::LatticePointTriangulation) ||
+        CPs.test(ConeProperty::AllGeneratorsTriangulation) || CPs.test(ConeProperty::Triangulation) ||
+        CPs.test(ConeProperty::PlacingTriangulation))  // Pulling is separate
         CPs.set(ConeProperty::BasicTriangulation);
 
     // NoGradingDenom ==> Grading
@@ -510,20 +607,8 @@ void ConeProperties::set_preconditions(bool inhomogeneous, bool numberfield) {
         CPs.set(ConeProperty::SupportHyperplanes);  // to meke them computed if Symmetrize is used
     */
 
-    // Integral ==> Triangulation
-    if (CPs.test(ConeProperty::Integral)) {
-        // CPs.set(ConeProperty::Multiplicity);
-        CPs.set(ConeProperty::BasicTriangulation);
-    }
-
-    // VirtualMultiplicity ==> Triangulation
-    if (CPs.test(ConeProperty::VirtualMultiplicity)) {
-//         // CPs.set(ConeProperty::Multiplicity);
-        CPs.set(ConeProperty::BasicTriangulation);
-    }
-
     // we want an ordinary triangulation if one is asked for
-    if(CPs.test(ConeProperty::BasicTriangulation) && !numberfield)
+    if (CPs.test(ConeProperty::BasicTriangulation) && !numberfield)
         CPs.set(ConeProperty::NoSubdivision);
 
     // WeightedEhrhartQuasiPolynomial ==> WeightedEhrhartSeries
@@ -577,11 +662,11 @@ void ConeProperties::set_preconditions(bool inhomogeneous, bool numberfield) {
         CPs.reset(ConeProperty::Approximate);  // or by approximation or projection if the
         CPs.reset(ConeProperty::Projection);   // Stanley decomposition must be computed anyway
     }
-    
+
     // inhomogeneous ==> (AffineDim >==> SupportHyperplanes)
     if (inhomogeneous && CPs.test(ConeProperty::AffineDim))
         CPs.set(ConeProperty::SupportHyperplanes);
-    
+
     // inhomogeneous ==> (RecessionRank >==> SupportHyperplanes)
     if (inhomogeneous && CPs.test(ConeProperty::RecessionRank))
         CPs.set(ConeProperty::SupportHyperplanes);
@@ -613,6 +698,28 @@ void ConeProperties::set_preconditions(bool inhomogeneous, bool numberfield) {
         CPs.set(ConeProperty::ExtremeRays);
 }
 
+void ConeProperties::check_compatibility_with_polynomial_constraints(bool inhomogeneous){
+
+    if(test(ConeProperty::ProjectionFloat))
+        throw BadInputException("ProjectionFloat not allowed with polynomial constraints");
+    ConeProperties wanted((*this).intersection_with(all_goals()));
+    wanted.reset(ConeProperty::Deg1Elements);
+    wanted.reset(ConeProperty::ModuleGenerators);
+    wanted.reset(ConeProperty::LatticePoints);
+    wanted.reset(ConeProperty::SupportHyperplanes);
+    wanted.reset(ConeProperty::ExtremeRays);
+    wanted.reset(ConeProperty::VerticesOfPolyhedron);
+    wanted.reset(ConeProperty::MaximalSubspace);
+    wanted.reset(ConeProperty::AffineDim);
+    wanted.reset(ConeProperty::NumberLatticePoints);
+    if(inhomogeneous)
+        wanted.reset(ConeProperty::HilbertBasis);
+    if(wanted.any()){
+        errorOutput() << wanted << endl;
+        throw BadInputException("One of the goals in the last line not allowed with polynomial constraints.");
+    }
+}
+
 void ConeProperties::check_Q_permissible(bool after_implications) {
     ConeProperties copy(*this);
     copy.reset(ConeProperty::SupportHyperplanes);
@@ -623,10 +730,13 @@ void ConeProperties::check_Q_permissible(bool after_implications) {
     copy.reset(ConeProperty::BasicTriangulation);
     copy.reset(ConeProperty::LatticePointTriangulation);
     copy.reset(ConeProperty::AllGeneratorsTriangulation);
+    copy.reset(ConeProperty::PullingTriangulation);
+    copy.reset(ConeProperty::PlacingTriangulation);
     copy.reset(ConeProperty::ConeDecomposition);
     copy.reset(ConeProperty::DefaultMode);
     copy.reset(ConeProperty::Generators);
     copy.reset(ConeProperty::Sublattice);
+    copy.reset(ConeProperty::WritePreComp);
     copy.reset(ConeProperty::MaximalSubspace);
     copy.reset(ConeProperty::Equations);
     copy.reset(ConeProperty::Dehomogenization);
@@ -662,6 +772,7 @@ void ConeProperties::check_Q_permissible(bool after_implications) {
     copy.reset(ConeProperty::DualFVector);
     copy.reset(ConeProperty::DualIncidence);
     copy.reset(ConeProperty::AmbientAutomorphisms);
+    copy.reset(ConeProperty::InputAutomorphisms);
     copy.reset(ConeProperty::Automorphisms);
     copy.reset(ConeProperty::CombinatorialAutomorphisms);
     copy.reset(ConeProperty::EuclideanAutomorphisms);
@@ -671,6 +782,12 @@ void ConeProperties::check_Q_permissible(bool after_implications) {
     copy.reset(ConeProperty::TestSmallPyramids);
     copy.reset(ConeProperty::FullConeDynamic);
     copy.reset(ConeProperty::ExcludedFaces);
+    copy.reset(ConeProperty::GroebnerBasis);
+    copy.reset(ConeProperty::MarkovBasis);
+    copy.reset(ConeProperty::SingleLatticePoint);
+    copy.reset(ConeProperty::SingleLatticePointInternal);
+    copy.reset(ConeProperty::NoCoarseProjection);
+    copy.reset(ConeProperty::NoPatching);
 
     if (after_implications) {
         copy.reset(ConeProperty::Multiplicity);
@@ -684,16 +801,20 @@ void ConeProperties::check_Q_permissible(bool after_implications) {
 }
 
 void ConeProperties::check_conflicting_variants() {
-    if ((CPs.test(ConeProperty::BottomDecomposition) && CPs.test(ConeProperty::NoBottomDec)) ||
+    if ((CPs.test(ConeProperty::BottomDecomposition) &&
+         (CPs.test(ConeProperty::NoBottomDec) || CPs.test(ConeProperty::KeepOrder))) ||
         (CPs.test(ConeProperty::DualMode) && CPs.test(ConeProperty::PrimalMode)) ||
         (CPs.test(ConeProperty::Symmetrize) && CPs.test(ConeProperty::NoSymmetrization)) ||
         (CPs.test(ConeProperty::Projection) && CPs.test(ConeProperty::NoProjection)) ||
         (CPs.test(ConeProperty::Projection) && CPs.test(ConeProperty::ProjectionFloat)) ||
         (CPs.test(ConeProperty::NoProjection) && CPs.test(ConeProperty::ProjectionFloat)) ||
         (CPs.test(ConeProperty::NoDescent) && CPs.test(ConeProperty::Descent)) ||
+        (CPs.test(ConeProperty::NoSignedDec) && CPs.test(ConeProperty::SignedDec)) ||
         (CPs.test(ConeProperty::Symmetrize) && CPs.test(ConeProperty::Descent)) ||
+        (CPs.test(ConeProperty::Descent) && CPs.test(ConeProperty::SignedDec)) ||
+        // (CPs.test(ConeProperty::Symmetrize) && CPs.test(ConeProperty::SignedDec)) ||
         (CPs.test(ConeProperty::Dynamic) && CPs.test(ConeProperty::Static)))
-    throw BadInputException("Contradictory algorithmic variants in options.");
+        throw BadInputException("Contradictory algorithmic variants in options.");
 
     size_t nr_var = 0;
     if (CPs.test(ConeProperty::DualMode))
@@ -712,59 +833,51 @@ void ConeProperties::check_conflicting_variants() {
 
 void ConeProperties::check_sanity(bool inhomogeneous) {  //, bool input_automorphisms) {
 
-    if (CPs.test(ConeProperty::IsTriangulationNested) || CPs.test(ConeProperty::IsTriangulationPartial) )
+    if (CPs.test(ConeProperty::IsTriangulationNested) || CPs.test(ConeProperty::IsTriangulationPartial))
         throw BadInputException("ConeProperty not allowed in compute().");
 
     if ((CPs.test(ConeProperty::Approximate) || CPs.test(ConeProperty::DualMode)) && CPs.test(ConeProperty::NumberLatticePoints))
         throw BadInputException("NumberLatticePoints not compuiable with DualMode or Approximate.");
-    
+
     size_t nr_triangs = 0;
-    if(CPs.test(ConeProperty::UnimodularTriangulation))
+    if (CPs.test(ConeProperty::UnimodularTriangulation))
         nr_triangs++;
-    if(CPs.test(ConeProperty::LatticePointTriangulation))
+    if (CPs.test(ConeProperty::LatticePointTriangulation))
         nr_triangs++;
-    if(CPs.test(ConeProperty::AllGeneratorsTriangulation))
+    if (CPs.test(ConeProperty::AllGeneratorsTriangulation))
         nr_triangs++;
-    
-    if(nr_triangs >0 && (CPs.test(ConeProperty::ConeDecomposition) || CPs.test(ConeProperty::StanleyDec) ) )
-        throw BadInputException("ConeDecomposition or StanleyDec cannot be combined with refined triangulation");
-    
-    if(CPs.test(ConeProperty::Triangulation))
+    if (CPs.test(ConeProperty::PullingTriangulation))
+        nr_triangs++;
+    if (CPs.test(ConeProperty::PlacingTriangulation))
         nr_triangs++;
 
-    if(nr_triangs > 1)
+    if (nr_triangs > 0 && (CPs.test(ConeProperty::ConeDecomposition) || CPs.test(ConeProperty::StanleyDec)))
+        throw BadInputException("ConeDecomposition or StanleyDec cannot be combined with refined triangulation");
+
+    if (CPs.test(ConeProperty::Triangulation))
+        nr_triangs++;
+
+    if (nr_triangs > 1)
         throw BadInputException("Only one type of triangulation allowed.");
-    
-    
-    bool something_to_do_primal = CPs.test(ConeProperty::FaceLattice)|| CPs.test(ConeProperty::FVector)
-                                            || CPs.test(ConeProperty::Incidence);
-                                            
-    bool something_to_do_dual = CPs.test(ConeProperty::DualFaceLattice)|| CPs.test(ConeProperty::DualFVector)
-                                            || CPs.test(ConeProperty::DualIncidence);
-                                            
-    if(something_to_do_dual && something_to_do_primal)
+
+    bool something_to_do_primal =
+        CPs.test(ConeProperty::FaceLattice) || CPs.test(ConeProperty::FVector) || CPs.test(ConeProperty::Incidence);
+
+    bool something_to_do_dual =
+        CPs.test(ConeProperty::DualFaceLattice) || CPs.test(ConeProperty::DualFVector) || CPs.test(ConeProperty::DualIncidence);
+
+    if (something_to_do_dual && something_to_do_primal)
         throw BadInputException("Only one of primal or dual face lattice/f-vector/incidence allowed");
 
-    size_t automs = 0;
-    if (CPs.test(ConeProperty::Automorphisms))
-        automs++;
-    if (CPs.test(ConeProperty::CombinatorialAutomorphisms))
-        automs++;
-    if (CPs.test(ConeProperty::AmbientAutomorphisms))
-        automs++;
-    if (CPs.test(ConeProperty::RationalAutomorphisms))
-        automs++;
-    if (CPs.test(ConeProperty::EuclideanAutomorphisms))
-        automs++;
-    if (automs > 1)
+    if (intersection_with(all_automorphisms()).count() > 1)
         throw BadInputException("Only one type of automorphism group allowed.");
-    
-    if(inhomogeneous && intersection_with(only_homogeneous_props()).any()){
+
+    if (inhomogeneous && intersection_with(only_homogeneous_props()).any()) {
         errorOutput() << *this << endl;
         throw BadInputException(" One of the goals in last line not computable in the inhomogeneous case.");
     }
-    
-    if(!inhomogeneous && intersection_with(only_inhomogeneous_props()).any()){
+
+    if (!inhomogeneous && intersection_with(only_inhomogeneous_props()).any()) {
         errorOutput() << *this << endl;
         throw BadInputException(" One of the goals not computable in the homogeneous case.");
     }
@@ -789,6 +902,9 @@ vector<string> initializeCPN() {
     CPN.at(ConeProperty::UnimodularTriangulation) = "UnimodularTriangulation";
     CPN.at(ConeProperty::LatticePointTriangulation) = "LatticePointTriangulation";
     CPN.at(ConeProperty::AllGeneratorsTriangulation) = "AllGeneratorsTriangulation";
+    CPN.at(ConeProperty::PullingTriangulation) = "PullingTriangulation";
+    CPN.at(ConeProperty::PullingTriangulationInternal) = "PullingTriangulationInternal";
+    CPN.at(ConeProperty::PlacingTriangulation) = "PlacingTriangulation";
     CPN.at(ConeProperty::Multiplicity) = "Multiplicity";
     CPN.at(ConeProperty::Volume) = "Volume";
     CPN.at(ConeProperty::RenfVolume) = "RenfVolume";
@@ -807,6 +923,8 @@ vector<string> initializeCPN() {
     CPN.at(ConeProperty::IsDeg1ExtremeRays) = "IsDeg1ExtremeRays";
     CPN.at(ConeProperty::IsDeg1HilbertBasis) = "IsDeg1HilbertBasis";
     CPN.at(ConeProperty::IsIntegrallyClosed) = "IsIntegrallyClosed";
+    CPN.at(ConeProperty::IsSerreR1) = "IsSerreR1";
+    CPN.at(ConeProperty::IsLatticeIdealToric) = "IsLatticeIdealToric";
     CPN.at(ConeProperty::WitnessNotIntegrallyClosed) = "WitnessNotIntegrallyClosed";
     CPN.at(ConeProperty::OriginalMonoidGenerators) = "OriginalMonoidGenerators";
     CPN.at(ConeProperty::IsReesPrimary) = "IsReesPrimary";
@@ -817,6 +935,7 @@ vector<string> initializeCPN() {
     CPN.at(ConeProperty::Dehomogenization) = "Dehomogenization";
     CPN.at(ConeProperty::InclusionExclusionData) = "InclusionExclusionData";
     CPN.at(ConeProperty::Sublattice) = "Sublattice";
+    CPN.at(ConeProperty::WritePreComp) = "WritePreComp";
     CPN.at(ConeProperty::ClassGroup) = "ClassGroup";
     CPN.at(ConeProperty::ModuleGeneratorsOverOriginalMonoid) = "ModuleGeneratorsOverOriginalMonoid";
     CPN.at(ConeProperty::Approximate) = "Approximate";
@@ -828,15 +947,15 @@ vector<string> initializeCPN() {
     CPN.at(ConeProperty::ProjectCone) = "ProjectCone";
     CPN.at(ConeProperty::MaximalSubspace) = "MaximalSubspace";
     CPN.at(ConeProperty::ConeDecomposition) = "ConeDecomposition";
-
     CPN.at(ConeProperty::Automorphisms) = "Automorphisms";
     CPN.at(ConeProperty::AmbientAutomorphisms) = "AmbientAutomorphisms";
+    CPN.at(ConeProperty::InputAutomorphisms) = "InputAutomorphisms";
     CPN.at(ConeProperty::RationalAutomorphisms) = "RationalAutomorphisms";
     CPN.at(ConeProperty::EuclideanAutomorphisms) = "EuclideanAutomorphisms";
     CPN.at(ConeProperty::CombinatorialAutomorphisms) = "CombinatorialAutomorphisms";
     CPN.at(ConeProperty::ExploitAutomsVectors) = "ExploitAutomsVectors";
-    CPN.at(ConeProperty::ExploitAutomsMult) = "ExploitAutomsMult";
-
+    CPN.at(ConeProperty::ExploitIsosMult) = "ExploitIsosMult";
+    CPN.at(ConeProperty::StrictIsoTypeCheck) = "StrictIsoTypeCheck";
     CPN.at(ConeProperty::HSOP) = "HSOP";
     CPN.at(ConeProperty::NoBottomDec) = "NoBottomDec";
     CPN.at(ConeProperty::PrimalMode) = "PrimalMode";
@@ -896,11 +1015,29 @@ vector<string> initializeCPN() {
     CPN.at(ConeProperty::DualFaceLattice) = "DualFaceLattice";
     CPN.at(ConeProperty::DualFVector) = "DualFVector";
     CPN.at(ConeProperty::DualIncidence) = "DualIncidence";
+    CPN.at(ConeProperty::SingularLocus) = "SingularLocus";
+    CPN.at(ConeProperty::CodimSingularLocus) = "CodimSingularLocus";
     CPN.at(ConeProperty::Dynamic) = "Dynamic";
     CPN.at(ConeProperty::Static) = "Static";
+    CPN.at(ConeProperty::SignedDec) = "SignedDec";
+    CPN.at(ConeProperty::NoSignedDec) = "NoSignedDec";
+    CPN.at(ConeProperty::FixedPrecision) = "FixedPrecision";
+    CPN.at(ConeProperty::DistributedComp) = "DistributedComp";
+    CPN.at(ConeProperty::MarkovBasis) = "MarkovBasis";
+    CPN.at(ConeProperty::GroebnerBasis) = "GroebnerBasis";
+    CPN.at(ConeProperty::Lex) = "Lex";
+    CPN.at(ConeProperty::RevLex) = "RevLex";
+    CPN.at(ConeProperty::DegLex) = "DegLex";
+    CPN.at(ConeProperty::NoPatching) = "NoPatching";
+    CPN.at(ConeProperty::NoCoarseProjection) = "NoCoarseProjection";
+    CPN.at(ConeProperty::SingleLatticePoint) = "SingleLatticePoint";
+    CPN.at(ConeProperty::SingleLatticePointInternal) = "SingleLatticePointInternal";
+    CPN.at(ConeProperty::Representations) = "Representations";
+    CPN.at(ConeProperty::MaxDegRepresentations) = "MaxDegRepresentations";
+    CPN.at(ConeProperty::ConeForMonoid) = "ConeForMonoid";
 
     // detect changes in size of Enum, to remember to update CPN!
-    static_assert(ConeProperty::EnumSize == 121, "ConeProperties Enum size does not fit! Update cone_property.cpp!");
+    static_assert(ConeProperty::EnumSize == 147, "ConeProperties Enum size does not fit! Update cone_property.cpp!");
     // assert all fields contain an non-empty string
     for (size_t i = 0; i < ConeProperty::EnumSize; i++) {
         assert(CPN.at(i).size() > 0);
