@@ -42,18 +42,16 @@ namespace libnormaliz {
 static int xalloc = std::ios_base::xalloc();
 
 // Normaliz implementation of deprecated e-antic functions
-
 std::istream & nmz_set_pword(boost::intrusive_ptr<const renf_class> our_renf, std::istream & is)
 {
     is.pword(xalloc) = const_cast<void*>(reinterpret_cast<const void*>(&*our_renf));
     return is;
 }
-
-
 boost::intrusive_ptr<const renf_class> nmz_get_pword(std::istream& is) {
     return reinterpret_cast<renf_class*>(is.pword(xalloc));
 }
 #endif
+//---------------------------------------------------------
 
 
 // To be used in input.cpp
@@ -90,7 +88,6 @@ inline void string2coeff(renf_elem_class& coeff, istream& in, const string& s) {
 
     try {
         coeff = renf_elem_class(*nmz_get_pword(in), s);
-        // coeff = renf_elem_class(*renf_class::get_pword(in), s);
     } catch (const std::exception& e) {
         cerr << e.what() << endl;
         throw BadInputException("Illegal number string " + s + " in input, Exiting.");
@@ -295,7 +292,7 @@ void process_constraint(const string& rel,
             return;
         }
     }
-    throw BadInputException("Illegal constrint type " + rel + " !");
+    throw BadInputException("Illegal constraint type " + rel + " !");
 }
 
 template <typename Number>
@@ -713,6 +710,21 @@ void read_polynomial(istream& in, string& polynomial) {
     }
 }
 
+void read_polynomial_constraints(istream& in, vector<string>& polynomial_constraints) {
+
+    int nr_constraints;
+    in >> nr_constraints;
+    if(in.fail() || nr_constraints<= 0)
+        throw BadInputException("Failure in reading number of polynomial constraints!");
+
+    string equ;
+    for(int i = 0; i < nr_constraints; ++i){
+        read_polynomial(in, equ);
+        polynomial_constraints.push_back(equ);
+        equ.clear();
+    }
+}
+
 template <typename Number>
 bool read_formatted_matrix(istream& in, Matrix<Number>& input_Matrix, bool transpose) {
     vector<vector<Number> > input_mat;
@@ -823,7 +835,8 @@ renf_class_shared read_number_field(istream& in) {
 }
 #endif
 
-void read_num_param(istream& in, map<NumParam::Param, long>& num_param_input, NumParam::Param numpar, const string& type_string) {
+void read_num_param(istream& in, map<NumParam::Param, long>& num_param_input,
+                    NumParam::Param numpar, const string& type_string) {
     long value;
     in >> value;
     if (in.fail())
@@ -831,12 +844,49 @@ void read_num_param(istream& in, map<NumParam::Param, long>& num_param_input, Nu
     num_param_input[numpar] = value;
 }
 
+template <typename Number>
+void convert_equ_to_inequ(InputMap<Number>& Input, const InputType& equ, const InputType inequ){
+
+    Number MinusOne = -1;
+
+    if(Input.find(equ) != Input.end() && Input[equ].nr_of_rows() > 0){
+        if(Input.find(inequ) == Input.end())
+            Input[inequ] = Matrix<Number>(0, Input[equ][0].size());
+        for(size_t i =0; i< Input[equ].nr_of_rows(); ++i){
+            Input[inequ].append(Input[equ][i]);
+            Input[inequ].append(Input[equ][i]);
+            v_scalar_multiplication<Number>(Input[inequ][Input[inequ].nr_of_rows()-1], MinusOne);
+        }
+        Input[equ].resize(0, Input[equ][0].size());
+    }
+
+}
+
+template <typename Number>
+void convert_equ_to_inequ(InputMap<Number>& Input,  const long dim){
+
+    bool exists_default_breaker = false;
+    for(auto& T: Input){
+        if(is_inequalities(T.first) || is_generators(T.first)){
+            exists_default_breaker = true;
+            break;
+        }
+    }
+
+    convert_equ_to_inequ<Number>(Input, Type::equations, Type::inequalities);
+    convert_equ_to_inequ<Number>(Input, Type::inhom_equations, Type::inhom_inequalities);
+    if(exists_default_breaker)
+        return;
+    Matrix<Number> unit_mat(dim); // must add unit_mat of inequalities to imitate default befavior
+    save_matrix(Input, Type::inequalities, unit_mat); // if no inequalities in input
+}
+
 template <typename Number>
 InputMap<Number> readNormalizInput(istream& in,
-                                                                 OptionsHandler& options,
-                                                                 map<NumParam::Param, long>& num_param_input,
-                                                                 string& polynomial,
-                                                                 renf_class_shared& number_field) {
+                                            OptionsHandler& options,
+                                            map<NumParam::Param, long>& num_param_input,
+                                            map<PolyParam::Param, vector<string> >& poly_param_input,
+                                            renf_class_shared& number_field) {
     string type_string;
     long i, j;
     long nr_rows, nr_columns, nr_rows_or_columns;
@@ -844,8 +894,10 @@ InputMap<Number> readNormalizInput(istream& in,
     Number number;
     ConeProperty::Enum cp;
     NumParam::Param numpar;
+    PolyParam::Param polypar;
     set<NumParam::Param> num_par_already_set;
     bool we_have_a_polynomial = false;
+    bool convert_equations = false;
 
     InputMap<Number> input_map;
 
@@ -856,8 +908,9 @@ InputMap<Number> readNormalizInput(istream& in,
     }
     bool new_input_syntax = !std::isdigit(c);
 
+    long dim;
+
     if (new_input_syntax) {
-        long dim;
         while (in.peek() == '/') {
             skip_comment(in);
             in >> std::ws;
@@ -913,6 +966,26 @@ InputMap<Number> readNormalizInput(istream& in,
                     num_par_already_set.insert(numpar);
                     continue;
                 }
+               if (isPolyParam(polypar, type_string)) {
+                        if(type_string == "polynomial"){
+                        if (we_have_a_polynomial)
+                                throw BadInputException("Only one polynomial allowed");
+                            we_have_a_polynomial = true;
+                            string poly_str;
+                            read_polynomial(in, poly_str);
+                            poly_param_input[PolyParam::polynomial].push_back(poly_str);
+                        }
+                        else{
+                            vector<string> poly_cosnts;
+                            read_polynomial_constraints(in, poly_cosnts);
+                            poly_param_input[polypar].insert(poly_param_input[polypar].end(),
+                                                             poly_cosnts.begin(), poly_cosnts.end());
+                        }
+                        continue;
+                }
+
+                // One could think that the following are superfluous.
+                // BUT: they take care of having the options in the inpput fike and not ón the command line
                 if (type_string == "LongLong") {
                     options.activateInputFileLongLong();
                     continue;
@@ -921,6 +994,10 @@ InputMap<Number> readNormalizInput(istream& in,
                     options.activateNoExtRaysOutput();
                     continue;
                 }
+                if (type_string == "BinomialsPacked") {
+                    options.activateBinomialsPacked();
+                    continue;
+                }
                 if (type_string == "NoHilbertBasisOutput") {
                     options.activateNoHilbertBasisOutput();
                     continue;
@@ -933,6 +1010,7 @@ InputMap<Number> readNormalizInput(istream& in,
                     options.activateNoSuppHypsOutput();
                     continue;
                 }
+
                 if (type_string == "number_field") {
 #ifndef ENFNORMALIZ
                     throw BadInputException("number_field only allowed for Normaliz with e-antic");
@@ -978,15 +1056,13 @@ InputMap<Number> readNormalizInput(istream& in,
                     read_constraints(in, dim, input_map, true);
                     continue;
                 }
-                if (type_string == "polynomial") {
-                    if (we_have_a_polynomial)
-                        throw BadInputException("Only one polynomial allowed");
-                    read_polynomial(in, polynomial);
-                    we_have_a_polynomial = true;
+                if (type_string == "convert_equations") {
+                    convert_equations = true;
                     continue;
                 }
 
                 input_type = to_type(type_string);
+
                 if (dim_known)
                     nr_columns = dim + type_nr_columns_correction(input_type);
 
@@ -1204,20 +1280,23 @@ InputMap<Number> readNormalizInput(istream& in,
             save_matrix(input_map, input_type, M);
         }
     }
+    if(convert_equations){
+            convert_equ_to_inequ(input_map, dim);
+    }
     return input_map;
 }
 
 template InputMap<mpq_class> readNormalizInput(istream& in,
                                                                              OptionsHandler& options,
                                                                              map<NumParam::Param, long>& num_param_input,
-                                                                             string& polynomial,
+                                                                             map<PolyParam::Param, vector<string> >& poly_param_input,
                                                                              renf_class_shared& number_field);
 
 #ifdef ENFNORMALIZ
 template InputMap<renf_elem_class> readNormalizInput(istream& in,
                                                                                    OptionsHandler& options,
                                                                                    map<NumParam::Param, long>& num_param_input,
-                                                                                   string& polynomial,
+                                                                                   map<PolyParam::Param, vector<string> >& poly_param_input,
                                                                                    renf_class_shared& number_field);
 #endif
 
