@@ -58,7 +58,7 @@ void printHeader() {
 #endif
     cout << "                                                       \\...|" << endl;
     cout << "     (C) The Normaliz Team, University of Osnabrueck    \\..|" << endl;
-    cout << "                        April 2022                       \\.|" << endl;
+    cout << "                     January 2023                        \\.|" << endl;
     cout << "                                                          \\|" << endl;
     string optional_packages = package_string();
     if (optional_packages.size() > 0) {
@@ -87,7 +87,7 @@ void printHelp(char* command) {
     cout << "  -G\tcheck Gorenstein" << endl;
 
     cout << endl;
-    cout << "Algorithmic variants with short options (slection):" << endl;
+    cout << "Algorithmic variants with short options (selection):" << endl;
     cout << "  -d\t dual ode (includes Hilbert basis, unless combined with -1)" << endl;
     cout << "  -j\t project-and-lift" << endl;
     cout << "  -J\t project-and-lift with floating point arithmetic" << endl;
@@ -105,11 +105,12 @@ void printHelp(char* command) {
     cout << "      Automorphisms, EuclideanAutomorphisms, RationalA..., CombinatorialA..." << endl;
     cout << "      EhrhartSeries, LatticePoints, NumberLatticePoints" << endl;
     cout << "      FaceLattice, FVector, Incidence" << endl;
+    cout << "      MasrkovBasis, GroebnerBasis, Lex, DegLex, RevLex" << endl;
 
     cout << endl;
     cout << "Output and execution:" << endl;
     cout << "  -f, --files      write the files .out .gen .inv .cst" << endl;
-    cout << "  -a, --all-files  write all output files (except  .dec .tri .typ)" << endl;
+    cout << "  -a, --all-files  write all optional output files" << endl;
     cout << "      --<SUFFIX>   write the file .<SUFFIX> where <SUFFIX> can be one of" << endl;
     cout << "                   cst, egn, esp, ext, gen, ht1, inv, lat, mod, msp, typ" << endl;
 
@@ -117,7 +118,7 @@ void printHelp(char* command) {
     cout << "  -B, --BigInt     directly use indefinite precision arithmetic" << endl;
     cout << "      --LongLong   only use long long arithmetic, no conversion possible" << endl;
     cout << "  -i, --ignore     ignore the compute options set in the input file" << endl;
-    cout << "  -x=<T>           limit the number of threads to <T>" << endl;
+    cout << "  -x=<T>           limit the number of threads to <T>, -x=0 switches the bound off" << endl;
     cout << "  --OutputDir=<path> set a path for the output files (relative to current directory)" << endl;
     cout << "  -?, --help       print this help text and exit" << endl;
     cout << "  -c, --verbose    verbose (prints log data on terminal)" << endl;
@@ -136,6 +137,8 @@ int main(int argc, char* argv[]) {
     ProfilerStart("normaliz.prof");
 #endif
 
+    StartGlobalTime();
+
     /*cout << "Before AAA" << endl;
     renf_class K("a^2 - 5", "a", "2.0 +/- 1.0");
     cout << "Constructed" << endl;
@@ -178,6 +181,8 @@ int main(int argc, char* argv[]) {
     ProfilerStop();
 #endif
 
+    MeasureGlobalTime(verbose);
+
     exit(0);
 }
 
@@ -187,7 +192,7 @@ template <typename ConeType, typename InputNumberType>
 void compute_and_output(OptionsHandler& options,
                         const InputMap<InputNumberType>& input,
                         const map<NumParam::Param, long>& num_param_input,
-                        const string& polynomial,
+                        map<PolyParam::Param, vector<string> >& poly_param_input,
                         renf_class_shared number_field_ref,
                         InputMap<InputNumberType>& add_input) {
     Output<ConeType> Out;  // all the information relevant for output is collected in this object
@@ -204,10 +209,10 @@ void compute_and_output(OptionsHandler& options,
 
     options.activateDefaultMode();
 
-    Out.set_lattice_ideal_input(input.count(Type::lattice_ideal) > 0);
+    // Out.set_lattice_ideal_input(input.count(Type::lattice_ideal) > 0);
 
     Cone<ConeType> MyCone = Cone<ConeType>(input);
-    MyCone.setPolynomial(polynomial);
+    MyCone.setPolyParams(poly_param_input);
     MyCone.setNumericalParams(num_param_input);
     /*MyCone.setNrCoeffQuasiPol(nr_coeff_quasipol);
     MyCone.setExpansionDegree(expansion_degree);
@@ -229,6 +234,7 @@ void compute_and_output(OptionsHandler& options,
     } catch (const InterruptException& e) {
         std::cout << endl;
         std::cout << "Computation was interrupted." << endl;
+        std::cout << e.what() << endl;
         std::cout << "Writing only available data." << endl;
     }
     Out.setCone(MyCone);
@@ -236,6 +242,9 @@ void compute_and_output(OptionsHandler& options,
 
     signal(SIGINT, SIG_DFL);
 
+    // Output may call extra computations. It does so for the Hilbert quasipolynomial
+    // In order to throw the interrupt exception again, we disable it here.
+    nmz_interrupted = 0;
     Out.write_files();
 
     if (MyCone.isComputed(ConeProperty::IntegerHull)) {
@@ -346,7 +355,8 @@ int process_data(OptionsHandler& options, const string& command_line) {
             exit(1);
         }
 
-        string polynomial = "";  // these are default values
+        string polynomial;
+        vector<string> polynomial_equations;
         /*long nr_coeff_quasipol=-1;
         long expansion_degree=-1;
         long face_codim_bound=-1;*/
@@ -354,12 +364,12 @@ int process_data(OptionsHandler& options, const string& command_line) {
         InputMap<mpq_class> input, add_input;
         InputMap<renf_elem_class> renf_input, renf_add_input;
         map<NumParam::Param, long> num_param_input;
+        map<PolyParam::Param, vector<string> > poly_param_input;
         bool renf_read = false;
-
         renf_class_shared number_field;
 
         try {
-            input = readNormalizInput<mpq_class>(in, options, num_param_input, polynomial, number_field);
+            input = readNormalizInput<mpq_class>(in, options, num_param_input, poly_param_input,  number_field);
             if (nmz_interrupted)
                 exit(10);
         }
@@ -370,7 +380,7 @@ int process_data(OptionsHandler& options, const string& command_line) {
 
             in.close();
             in.open(file_in, ifstream::in);
-            renf_input = readNormalizInput<renf_elem_class>(in, options, num_param_input, polynomial, number_field);
+            renf_input = readNormalizInput<renf_elem_class>(in, options, num_param_input, poly_param_input, number_field);
             if (nmz_interrupted)
                 exit(10);
             renf_read = true;
@@ -401,18 +411,18 @@ int process_data(OptionsHandler& options, const string& command_line) {
             // if(options.getToCompute().test(ConeProperty::Dynamic))
             renf_add_input = extract_additional_input<renf_elem_class>(renf_input);
 
-            compute_and_output<renf_elem_class>(options, renf_input, num_param_input, polynomial, number_field, renf_add_input);
+            compute_and_output<renf_elem_class>(options, renf_input, num_param_input, poly_param_input, number_field, renf_add_input);
         }
         else {
             if (options.isUseLongLong()) {
                 // if(options.getToCompute().test(ConeProperty::Dynamic))
                 add_input = extract_additional_input<mpq_class>(input);
-                compute_and_output<long long>(options, input, num_param_input, polynomial, number_field, add_input);
+                compute_and_output<long long>(options, input, num_param_input, poly_param_input, number_field, add_input);
             }
             else {
                 // if(options.getToCompute().test(ConeProperty::Dynamic))
                 add_input = extract_additional_input<mpq_class>(input);
-                compute_and_output<mpz_class>(options, input, num_param_input, polynomial, number_field, add_input);
+                compute_and_output<mpz_class>(options, input, num_param_input, poly_param_input, number_field, add_input);
             }
         }
 
